@@ -6,7 +6,6 @@ import sys
 from pytype import config
 from pytype import datatypes
 from pytype import utils
-from pytype.tests import test_utils
 
 import unittest
 
@@ -14,40 +13,37 @@ import unittest
 class ConfigTest(unittest.TestCase):
 
   def test_basic(self):
+    version = sys.version_info[:2]
     argv = [
-        "-V", "3.6",
+        "-V", utils.format_version(version),
         "--use-pickled-files",
         "-o", "out.pyi",
         "--pythonpath", "foo:bar",
         "test.py"
     ]
     opts = config.Options(argv)
-    self.assertEqual(opts.python_version, (3, 6))
+    self.assertEqual(opts.python_version, version)
     self.assertEqual(opts.use_pickled_files, True)
     self.assertEqual(opts.pythonpath, ["foo", "bar"])
     self.assertEqual(opts.output, "out.pyi")
     self.assertEqual(opts.input, "test.py")
 
   def test_create(self):
-    opts = config.Options.create(input_filename="foo.py", python_version="3.6",
-                                 use_pickled_files=True)
+    version = sys.version_info[:2]
+    opts = config.Options.create(
+        input_filename="foo.py", python_version=utils.format_version(version),
+        use_pickled_files=True)
     self.assertEqual(opts.input, "foo.py")
     self.assertEqual(opts.use_pickled_files, True)
-    self.assertEqual(opts.python_version, (3, 6))
+    self.assertEqual(opts.python_version, version)
     exe, _ = opts.python_exe
-    if sys.version_info[:2] != (3, 6):
-      self.assertIn("python3", exe)
-    else:
-      self.assertIsNone(exe)
+    self.assertIsNone(exe)
 
     opts = config.Options.create(python_version=(2, 7), use_pickled_files=True)
     self.assertEqual(opts.use_pickled_files, True)
     self.assertEqual(opts.python_version, (2, 7))
     exe, _ = opts.python_exe
-    if sys.version_info[:2] != (2, 7) or utils.USE_ANNOTATIONS_BACKPORT:
-      self.assertIn("2.7", exe)
-    else:
-      self.assertIsNone(exe)
+    self.assertIn("2.7", exe)
 
   def test_analyze_annotated_check(self):
     argv = ["--check", "test.py"]
@@ -92,11 +88,6 @@ class ConfigTest(unittest.TestCase):
     ]:
       self._test_arg_conflict(arg1, arg2)
 
-  @test_utils.skipUnless37Available
-  def test_v37(self):
-    opts = config.Options(["-V3.7", "test.py"])
-    self.assertEqual(opts.python_version, (3, 7))
-
 
 class PostprocessorTest(unittest.TestCase):
 
