@@ -1,13 +1,13 @@
+# Lint as: python3
 """Code and data structures for storing and displaying errors."""
 
-from __future__ import print_function
-
 import collections
 import contextlib
 import csv
 import logging
 import re
 import sys
+from typing import Optional, Union
 
 from pytype import abstract
 from pytype import debug
@@ -549,8 +549,6 @@ class ErrorLog(ErrorLogBase):
       if bad_param and name == bad_param.name:
         type_str = self._print_as_expected_type(bad_param.expected)
         suffix = ": " + type_str + suffix
-      else:
-        suffix = suffix
       yield prefix, name, suffix
 
   def _iter_actual(self, sig, passed_args, bad_param):
@@ -868,8 +866,10 @@ class ErrorLog(ErrorLogBase):
             " and ".join(repr(operand) for operand in operands)),
         details=details.get("details"))
 
-  def invalid_annotation(self, stack, annot, details=None, name=None):
-    if annot is not None:
+  def invalid_annotation(
+      self, stack, annot: Optional[Union[str, abstract.AtomicAbstractValue]],
+      details=None, name=None):
+    if isinstance(annot, abstract.AtomicAbstractValue):
       annot = self._print_as_expected_type(annot)
     self._invalid_annotation(stack, annot, details, name)
 
@@ -948,11 +948,6 @@ class ErrorLog(ErrorLogBase):
     self.error(stack, "Invalid function type comment: %s" % comment,
                details=details)
 
-  @_error_name("invalid-type-comment")
-  def invalid_type_comment(self, stack, comment, details=None):
-    self.error(stack, "Invalid type comment: %s" % comment,
-               details=details)
-
   @_error_name("ignored-type-comment")
   def ignored_type_comment(self, filename, lineno, comment):
     self._add(Error(
